from unittest import TestCase

from cnam import get_cnam, get_phone_number
from fudge import Fake


class TestGetCnam(TestCase):

    def test_get_cnam_returns_cnam_for_valid_numbers(self):
        (Fake('requests.get')
                .expects_call()
                .with_args('https://api.opencnam.com/v1/phone/8182179229')
                .returns_fake()
                .expects('status_code')
                .returns(200)
                .expects('text')
                .returns('DEGGAS,RANDALL'))
        self.assertEquals(get_cnam(8182179229), 'DEGGAS,RANDALL')

    def test_get_cnam_returns_none_for_invalid_numbers(self):
        (Fake('requests.get')
                .expects_call()
                .with_args('https://api.opencnam.com/v1/phone/2001000000')
                .returns_fake()
                .expects('status_code')
                .returns(404))
        self.assertEquals(get_cnam(2001000000), None)
        

class TestGetPhoneNumber(TestCase):

    def test_get_phone_number_accepts_valid_10_digit_numbers(self):
        self.assertEquals(get_phone_number('2002000000'), 2002000000)
        self.assertEquals(get_phone_number('8182179229'), 8182179229)
        self.assertEquals(get_phone_number('9999999999'), 9999999999)

    def test_get_phone_number_accepts_valid_11_digit_numbers(self):
        self.assertEquals(get_phone_number('12002000000'), 2002000000)
        self.assertEquals(get_phone_number('18182179229'), 8182179229)
        self.assertEquals(get_phone_number('19999999999'), 9999999999)

    def test_get_phone_number_removes_non_numerics(self):
        self.assertEquals(get_phone_number('abc818abc217abc9229abc'), 8182179229)
        self.assertEquals(get_phone_number('__8182179229'), 8182179229)
        self.assertEquals(get_phone_number('!&@8182179229#>>'), 8182179229)

    def test_get_phone_number_disallows_short_numbers(self):
        self.assertRaises(SystemExit, get_phone_number, '')
        self.assertRaises(SystemExit, get_phone_number, '123')
        self.assertRaises(SystemExit, get_phone_number, '123456789')

    def test_get_phone_number_disallows_long_numbers(self):
        self.assertRaises(SystemExit, get_phone_number, '22345678901')
        self.assertRaises(SystemExit, get_phone_number, '223456789012')
        self.assertRaises(SystemExit, get_phone_number, '5234567890123')

    def test_get_phone_number_disallows_invalid_numbers(self):
        self.assertRaises(SystemExit, get_phone_number, '2001000000')
        self.assertRaises(SystemExit, get_phone_number, '2001999999')
